<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="500px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="人员数量:" prop="personCount" >
          <el-input v-model="state.form.personCount" placeholder="请输入人员数量" @input="state.form.personCount= state.form.personCount.replace(/[^\d]/g,'')"></el-input>
        </el-form-item>
        <el-form-item label="车辆数量:" prop="carCount" >
          <el-input v-model="state.form.carCount" placeholder="请输入车辆数量" @input="state.form.carCount= state.form.carCount.replace(/[^\d]/g,'')"></el-input>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {onMounted, reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";
import {listDept} from "@/api/system/dept";
import {listUser} from "@/api/system/user";
import {addTemplate, editTemplate} from "@/api/signAgreement/template";
import {addType, editType, getSignType} from "@/api/signAgreement/signType";
import {getInfo} from "@/api/login";
import {getToken} from "@/utils/auth";
import {verifyPhone} from "@/utils/validate";
import Cookies from "js-cookie";
import {addPeople} from "@/api/company/people";
import {addPeopleCar} from "@/api/company/peopleCar";

const uploadFileUrl = ref(import.meta.env.VITE_APP_BASE_API + "/common/upload"); // 上传文件服务器地址
const { proxy } = getCurrentInstance();
const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startPhone = ref('');

const state = reactive({
  form: {
    id: '',
    carCount: null,
    companyCode: '',
    personCount:null,
  },

  formRules:{
    carCount: [{ required: true, trigger: "blur", message:'请输入车辆数量' }],
    personCount: [{ required: true, trigger: "blur", message:'请选择人员数量' }],
  },
})
onMounted(()=>{

})


const openDialog = async (type,value) => {
  title.value = type === 'add' ? '新增' : '编辑'
  const info = JSON.parse(Cookies.get('userInfo'))
  state.form.companyCode = info.companynumber
  if(type === 'edit') {
    const data = JSON.parse(JSON.stringify(value))
    Object.keys(state.form).forEach(key => {
      if(data[key]){
        state.form[key] = data[key]
      }
    })
    startPhone.value = value.phone
  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  console.log('form',state.form)
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addPeopleCar(data)
      if(res.code == 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addPeopleCar(data)
      if(res.code == 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }

  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")
}
const reset = () => {
  state.form = {
    id: '',
    carCount: null,
    companyCode: '',
    personCount:null,
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  :deep(.el-form-item__content) {
    width: 100%;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
  .custom-iframe {
    border: 1px solid #9b9999;
    /* 隐藏原生滚动条 */
    overflow: hidden;
  }
}
</style>
